==> cpp11armadillo_0.2.5.tgz: cpp11armadillo/include/armadillo/mtGlue_meat.hpp <==
// SPDX-License-Identifier: Apache-2.0
//
// Copyright 2008-2016 Conrad Sanderson (http://conradsanderson.id.au)
// Copyright 2008-2016 National ICT Australia (NICTA)
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
// ------------------------------------------------------------------------

//! \addtogroup mtGlue
//! @{

template <typename out_eT, typename T1, typename T2, typename glue_type>
inline mtGlue<out_eT, T1, T2, glue_type>::mtGlue(const T1& in_A, const T2& in_B)
    : A(in_A), B(in_B) {
  arma_extra_debug_sigprint();
}

template <typename out_eT, typename T1, typename T2, typename glue_type>
inline mtGlue<out_eT, T1, T2, glue_type>::mtGlue(const T1& in_A, const T2& in_B,
                                                 const uword in_aux_uword)
    : A(in_A), B(in_B), aux_uword(in_aux_uword) {
  arma_extra_debug_sigprint();
}

template <typename out_eT, typename T1, typename T2, typename glue_type>
inline mtGlue<out_eT, T1, T2, glue_type>::~mtGlue() {
  arma_extra_debug_sigprint();
}

//! @}

==> cpp11armadillo_0.4.1.tgz: cpp11armadillo/include/armadillo/mtGlue_meat.hpp <==
// SPDX-License-Identifier: Apache-2.0
//
// Copyright 2008-2016 Conrad Sanderson (http://conradsanderson.id.au)
// Copyright 2008-2016 National ICT Australia (NICTA)
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
// ------------------------------------------------------------------------

//! \addtogroup mtGlue
//! @{

template <typename out_eT, typename T1, typename T2, typename glue_type>
inline mtGlue<out_eT, T1, T2, glue_type>::mtGlue(const T1& in_A, const T2& in_B)
    : A(in_A), B(in_B) {
  arma_debug_sigprint();
}

template <typename out_eT, typename T1, typename T2, typename glue_type>
inline mtGlue<out_eT, T1, T2, glue_type>::mtGlue(const T1& in_A, const T2& in_B,
                                                 const uword in_aux_uword)
    : A(in_A), B(in_B), aux_uword(in_aux_uword) {
  arma_debug_sigprint();
}

template <typename out_eT, typename T1, typename T2, typename glue_type>
inline mtGlue<out_eT, T1, T2, glue_type>::~mtGlue() {
  arma_debug_sigprint();
}

template <typename out_eT, typename T1, typename T2, typename glue_type>
template <typename eT2>
inline bool mtGlue<out_eT, T1, T2, glue_type>::is_alias(const Mat<eT2>& X) const {
  arma_debug_sigprint();

  return (A.is_alias(X) || B.is_alias(X));
}

//! @}
